(constant-time-eq? a b)Securely compares two byte arrays in constant time to prevent timing attacks.
Securely compares two byte arrays in constant time to prevent timing attacks.
(hash-key pepper!! token-map)Computes the final cryptographically bound HMAC-SHA512 hash. Binds the token to its specific structural context to prevent DB-level swaps.
Computes the final cryptographically bound HMAC-SHA512 hash. Binds the token to its specific structural context to prevent DB-level swaps.
(hmac-sha512 pepper!! data!!)Computes an HMAC-SHA512 over the raw data bytes using the backend pepper.
Computes an HMAC-SHA512 over the raw data bytes using the backend pepper.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |