(default-https? request)Heuristic HTTPS detector that works behind common reverse proxies.
Checks Ring :scheme, then X-Forwarded-* and Front-End-Https headers. Security note: only trust forwarded headers when requests come from a trusted reverse proxy / load balancer.
Heuristic HTTPS detector that works behind common reverse proxies. Checks Ring :scheme, then X-Forwarded-* and Front-End-Https headers. Security note: only trust forwarded headers when requests come from a trusted reverse proxy / load balancer.
(normalize settings-in)Merge user settings with sane defaults and validate. Guarantees all required V2 cryptographic parameters are present. Converts the pepper string into a UTF-8 byte array for the crypto engine.
Merge user settings with sane defaults and validate. Guarantees all required V2 cryptographic parameters are present. Converts the pepper string into a UTF-8 byte array for the crypto engine.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |